/*
  This program demonstrates how difficult it is in languages like
  Java (or C or C++) to instantiate a complex data structure like
  a binary tree. Below is code that instantiates the following tree.


                 a
                / \
              /     \
             b       c
            / \        \
          /     \        \
         d       e        f
                         /
                       /
                      g
                       \
                         \
                           h
*/

public class Main
{
   public static void main(String[] args)
   {
      // Here is the Java declaration of the above binary tree.
      BTree bTree1 = new BTree("a", new BTree("b", new BTree("d"), new BTree("e")), new BTree("c", null, new BTree("f", new BTree("g", null, new BTree("h")), null)));

      // Here is the exact same binary tree declaration,
      // but using indentation to make it more readable.
      BTree bTree2 = new BTree("a",
                              new BTree("b",
                                        new BTree("d"),
                                        new BTree("e")),
                              new BTree("c",
                                        null,
                                        new BTree("f",
                                                  new BTree("g",
                                                            null,
                                                            new BTree("h")),
                                                  null)));

      // Let us traverse the tree so that we can convince
      // ourselves that it was constructed correctly.
      // We should get "d b e a c g h f" for the preorder traversal.
      System.out.println( " Preorder traversal --> " + Traverse.preOrder( bTree1 ) + "\n" );
      System.out.println( "  Inorder traversal --> " + Traverse.inOrder( bTree1 ) + "\n" );
      System.out.println( "Postorder traversal --> " + Traverse.postOrder( bTree1 ) + "\n" );

      System.out.println( " Preorder traversal --> " + Traverse.preOrder( bTree2 ) + "\n" );
      System.out.println( "  Inorder traversal --> " + Traverse.inOrder( bTree2 ) + "\n" );
      System.out.println( "Postorder traversal --> " + Traverse.postOrder( bTree2 ) + "\n" );
   }//main

}//Main
